@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.20';
+$VERSION   = '1.24';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -223,77 +223,78 @@ my %SeenRuntimeLoader;
 
 # Pre-loaded module dependencies {{{
 my %Preload = (
-    'AnyDBM_File.pm'  => [qw( SDBM_File.pm )],
-    'AnyEvent.pm'     => 'sub',
-    'Authen/SASL.pm'  => 'sub',
-    'B/Hooks/EndOfScope.pm' => [qw( B/Hooks/EndOfScope/PP.pm B/Hooks/EndOfScope/XS.pm )],
-    'Bio/AlignIO.pm'  => 'sub',
-    'Bio/Assembly/IO.pm'  => 'sub',
-    'Bio/Biblio/IO.pm'  => 'sub',
-    'Bio/ClusterIO.pm'  => 'sub',
-    'Bio/CodonUsage/IO.pm'  => 'sub',
-    'Bio/DB/Biblio.pm'  => 'sub',
-    'Bio/DB/Flat.pm'  => 'sub',
-    'Bio/DB/GFF.pm'  => 'sub',
-    'Bio/DB/Taxonomy.pm'  => 'sub',
-    'Bio/Graphics/Glyph.pm'  => 'sub',
-    'Bio/MapIO.pm'  => 'sub',
-    'Bio/Matrix/IO.pm'  => 'sub',
-    'Bio/Matrix/PSM/IO.pm'  => 'sub',
-    'Bio/OntologyIO.pm'  => 'sub',
-    'Bio/PopGen/IO.pm'  => 'sub',
-    'Bio/Restriction/IO.pm'  => 'sub',
-    'Bio/Root/IO.pm'  => 'sub',
-    'Bio/SearchIO.pm'  => 'sub',
-    'Bio/SeqIO.pm'  => 'sub',
-    'Bio/Structure/IO.pm'  => 'sub',
-    'Bio/TreeIO.pm'  => 'sub',
-    'Bio/LiveSeq/IO.pm'  => 'sub',
-    'Bio/Variation/IO.pm'  => 'sub',
-    'Catalyst.pm' => sub {
+    'AnyDBM_File.pm'                    => [qw( SDBM_File.pm )],
+    'AnyEvent.pm'                       => 'sub',
+    'Authen/SASL.pm'                    => 'sub',
+    'B/Hooks/EndOfScope.pm'             => 
+        [qw( B/Hooks/EndOfScope/PP.pm B/Hooks/EndOfScope/XS.pm )],
+    'Bio/AlignIO.pm'                    => 'sub',
+    'Bio/Assembly/IO.pm'                => 'sub',
+    'Bio/Biblio/IO.pm'                  => 'sub',
+    'Bio/ClusterIO.pm'                  => 'sub',
+    'Bio/CodonUsage/IO.pm'              => 'sub',
+    'Bio/DB/Biblio.pm'                  => 'sub',
+    'Bio/DB/Flat.pm'                    => 'sub',
+    'Bio/DB/GFF.pm'                     => 'sub',
+    'Bio/DB/Taxonomy.pm'                => 'sub',
+    'Bio/Graphics/Glyph.pm'             => 'sub',
+    'Bio/MapIO.pm'                      => 'sub',
+    'Bio/Matrix/IO.pm'                  => 'sub',
+    'Bio/Matrix/PSM/IO.pm'              => 'sub',
+    'Bio/OntologyIO.pm'                 => 'sub',
+    'Bio/PopGen/IO.pm'                  => 'sub',
+    'Bio/Restriction/IO.pm'             => 'sub',
+    'Bio/Root/IO.pm'                    => 'sub',
+    'Bio/SearchIO.pm'                   => 'sub',
+    'Bio/SeqIO.pm'                      => 'sub',
+    'Bio/Structure/IO.pm'               => 'sub',
+    'Bio/TreeIO.pm'                     => 'sub',
+    'Bio/LiveSeq/IO.pm'                 => 'sub',
+    'Bio/Variation/IO.pm'               => 'sub',
+    'Catalyst.pm'                       => sub {
         return ('Catalyst/Runtime.pm',
                 'Catalyst/Dispatcher.pm',
                 _glob_in_inc('Catalyst/DispatchType', 1));
     },
-    'Catalyst/Engine.pm' => 'sub',
-    'CGI/Application/Plugin/Authentication.pm' => [qw( CGI/Application/Plugin/Authentication/Store/Cookie.pm )],
+    'Catalyst/Engine.pm'                => 'sub',
+    'CGI/Application/Plugin/Authentication.pm' => 
+        [qw( CGI/Application/Plugin/Authentication/Store/Cookie.pm )],
     'CGI/Application/Plugin/AutoRunmode.pm' => [qw( Attribute/Handlers.pm )],
-    'charnames.pm' => sub {
-        _find_in_inc('unicore/Name.pl') ? 'unicore/Name.pl' : 'unicode/Name.pl'
-    },
-    'Class/Load.pm' => [qw( Class/Load/PP.pm )],
-    'Class/MakeMethods.pm' => 'sub',
-    'Class/MethodMaker.pm' => 'sub',
-    'Config/Any.pm' =>'sub',
-    'Crypt/Random.pm' => sub {
+    'charnames.pm'                      => \&_unicore,
+    'Class/Load.pm'                     => [qw( Class/Load/PP.pm )],
+    'Class/MakeMethods.pm'              => 'sub',
+    'Class/MethodMaker.pm'              => 'sub',
+    'Config/Any.pm'                     =>'sub',
+    'Crypt/Random.pm'                   => sub {
         _glob_in_inc('Crypt/Random/Provider', 1);
     },
-    'Crypt/Random/Generator.pm' => sub {
+    'Crypt/Random/Generator.pm'         => sub {
         _glob_in_inc('Crypt/Random/Provider', 1);
     },
-    'Date/Manip.pm' => [qw( Date/Manip/DM5.pm Date/Manip/DM6.pm )],
-    'Date/Manip/Base.pm' => sub {
+    'Date/Manip.pm'                     => 
+        [qw( Date/Manip/DM5.pm Date/Manip/DM6.pm )],
+    'Date/Manip/Base.pm'                => sub {
         _glob_in_inc('Date/Manip/Lang', 1);
     },
-    'Date/Manip/TZ.pm' => sub {
+    'Date/Manip/TZ.pm'                  => sub {
         return (_glob_in_inc('Date/Manip/TZ', 1),
                 _glob_in_inc('Date/Manip/Offset', 1));
     },
     'DateTime/Format/Builder/Parser.pm' => 'sub',
-    'DateTime/Locale.pm' => 'sub',
-    'DateTime/TimeZone.pm' => 'sub',
-    'DBI.pm' => sub {
+    'DateTime/Format/Natural.pm'        => 'sub',
+    'DateTime/Locale.pm'                => 'sub',
+    'DateTime/TimeZone.pm'              => 'sub',
+    'DBI.pm'                            => sub {
         grep !/\bProxy\b/, _glob_in_inc('DBD', 1);
     },
-    'DBIx/Class.pm' => 'sub',
-    'DBIx/SearchBuilder.pm' => 'sub',
-    'DBIx/Perlish.pm' => [qw( attributes.pm )],
-    'DBIx/ReportBuilder.pm' => 'sub',
-    'Device/ParallelPort.pm' => 'sub',
-    'Device/SerialPort.pm' => [ qw(
-        termios.ph asm/termios.ph sys/termiox.ph sys/termios.ph sys/ttycom.ph
-    ) ],
-    'diagnostics.pm' => sub {
+    'DBIx/Class.pm'                     => 'sub',
+    'DBIx/SearchBuilder.pm'             => 'sub',
+    'DBIx/Perlish.pm'                   => [qw( attributes.pm )],
+    'DBIx/ReportBuilder.pm'             => 'sub',
+    'Device/ParallelPort.pm'            => 'sub',
+    'Device/SerialPort.pm'              => 
+        [qw( termios.ph asm/termios.ph sys/termiox.ph sys/termios.ph sys/ttycom.ph )],
+    'diagnostics.pm'                    => sub {
         # shamelessly taken and adapted from diagnostics.pm
         use Config;
         my($privlib, $archlib) = @Config{qw(privlibexp archlibexp)};
@@ -324,195 +325,202 @@ my %Preload = (
 
         return 'pod/perldiag.pod';
     },
-    'Email/Send.pm' => 'sub',
-    'Event.pm' => [ map "Event/$_.pm", qw(idle io signal timer var)],
-    'ExtUtils/MakeMaker.pm' => sub {
+    'Email/Send.pm'                     => 'sub',
+    'Event.pm'                          => sub {
+        map "Event/$_.pm", qw( idle io signal timer var );
+    },
+    'ExtUtils/MakeMaker.pm'             => sub {
         grep /\bMM_/, _glob_in_inc('ExtUtils', 1);
     },
-    'File/Basename.pm' => [qw( re.pm )],
-    'File/BOM.pm'      => [qw( Encode/Unicode.pm )],
-    'File/HomeDir.pm' => 'sub',
-    'File/Spec.pm'     => sub {
+    'File/Basename.pm'                  => [qw( re.pm )],
+    'File/BOM.pm'                       => [qw( Encode/Unicode.pm )],
+    'File/HomeDir.pm'                   => 'sub',
+    'File/Spec.pm'                      => sub {
         require File::Spec;
         map { my $name = $_; $name =~ s!::!/!g; "$name.pm" } @File::Spec::ISA;
     },
-    'Gtk2.pm' => [qw( Cairo.pm )], # Gtk2.pm does: eval "use Cairo;"
-    'HTTP/Message.pm' => [ qw(
-        URI/URL.pm          URI.pm
-    ) ],
-    'Image/ExifTool.pm' => sub {
+    'Gtk2.pm'                           => [qw( Cairo.pm )], # Gtk2.pm does: eval "use Cairo;"
+    'HTTP/Message.pm'                   => [qw( URI/URL.pm URI.pm )],
+    'Image/ExifTool.pm'                 => sub {
         return(
           (map $_->{name}, _glob_in_inc('Image/ExifTool', 0)), # also *.pl files
           qw( File/RandomAccess.pm ),
         );
     },
-    'Image/Info.pm' => sub {
+    'Image/Info.pm'                     => sub {
         return(
           _glob_in_inc('Image/Info', 1),
           qw( Image/TIFF.pm ),
         );
     },
-    'IO.pm' => [ qw(
+    'IO.pm'                             => [qw(
         IO/Handle.pm        IO/Seekable.pm      IO/File.pm
         IO/Pipe.pm          IO/Socket.pm        IO/Dir.pm
-    ) ],
-    'IO/Socket.pm'     => [qw( IO/Socket/UNIX.pm )],
-    'JSON.pm' => sub {
+    )],
+    'IO/Socket.pm'                      => [qw( IO/Socket/UNIX.pm )],
+    'JSON.pm'                           => sub {
         # add JSON/PP*.pm, JSON/PP/*.pm
         # and ignore other JSON::* modules (e.g. JSON/Syck.pm, JSON/Any.pm);
         # but accept JSON::XS, too (because JSON.pm might use it if present)
         return( grep /^JSON\/(PP|XS)/, _glob_in_inc('JSON', 1) );
     },
-    'Locale/Maketext/Lexicon.pm'    => 'sub',
-    'Locale/Maketext/GutsLoader.pm' => [qw( Locale/Maketext/Guts.pm )],
-    'Log/Any.pm'                => 'sub',
-    'Log/Log4perl.pm'           => 'sub',
-    'Log/Report/Dispatcher.pm'  => 'sub',
-    'LWP/MediaTypes.pm'         => [qw( LWP/media.types )],
-    'LWP/Parallel.pm'           => sub {
+    'List/MoreUtils.pm'                 => 'sub',
+    'List/SomeUtils.pm'                 => 'sub',
+    'Locale/Maketext/Lexicon.pm'        => 'sub',
+    'Locale/Maketext/GutsLoader.pm'     => [qw( Locale/Maketext/Guts.pm )],
+    'Log/Any.pm'                        => 'sub',
+    'Log/Dispatch.pm'                   => 'sub',
+    'Log/Log4perl.pm'                   => 'sub',
+    'Log/Report/Dispatcher.pm'          => 'sub',
+    'LWP/MediaTypes.pm'                 => [qw( LWP/media.types )],
+    'LWP/Parallel.pm'                   => sub {
         _glob_in_inc( 'LWP/Parallel', 1 ),
         qw(
             LWP/ParallelUA.pm       LWP/UserAgent.pm
             LWP/RobotPUA.pm         LWP/RobotUA.pm
         ),
     },
-    'LWP/Parallel/UserAgent.pm' => [qw( LWP/Parallel.pm )],
-    'LWP/UserAgent.pm'          => sub {
+    'LWP/Parallel/UserAgent.pm'         => [qw( LWP/Parallel.pm )],
+    'LWP/UserAgent.pm'                  => sub {
         return( 
           qw( URI/URL.pm URI/http.pm LWP/Protocol/http.pm ),
           _glob_in_inc("LWP/Authen", 1),
           _glob_in_inc("LWP/Protocol", 1),
         );
     },
-    'Mail/Audit.pm'                => 'sub',
-    'Math/BigInt.pm'                => 'sub',
-    'Math/BigFloat.pm'              => 'sub',
-    'Math/Symbolic.pm'              => 'sub',
-    'MIME/Decoder.pm'               => 'sub',
-    'MIME/Types.pm'                 => [qw( MIME/types.db )],
-    'Module/Build.pm'               => 'sub',
-    'Module/Pluggable.pm'           => sub {
+    'Mail/Audit.pm'                     => 'sub',
+    'Math/BigInt.pm'                    => 'sub',
+    'Math/BigFloat.pm'                  => 'sub',
+    'Math/Symbolic.pm'                  => 'sub',
+    'MIME/Decoder.pm'                   => 'sub',
+    'MIME/Types.pm'                     => [qw( MIME/types.db )],
+    'Module/Build.pm'                   => 'sub',
+    'Module/Pluggable.pm'               => sub {
         _glob_in_inc('$CurrentPackage/Plugin', 1);
     },
-    'Moose.pm'                      => sub {
+    'Moose.pm'                          => sub {
         _glob_in_inc('Moose', 1),
         _glob_in_inc('Class/MOP', 1),
     },
-    'MooseX/AttributeHelpers.pm'    => 'sub',
-    'MooseX/POE.pm'                 => sub {
+    'MooseX/AttributeHelpers.pm'        => 'sub',
+    'MooseX/POE.pm'                     => sub {
         _glob_in_inc('MooseX/POE', 1),
         _glob_in_inc('MooseX/Async', 1),
     },
-    'Mozilla/CA.pm'                 => [qw( Mozilla/CA/cacert.pem )],
-    'MozRepl.pm'                    => sub {
+    'Mozilla/CA.pm'                     => [qw( Mozilla/CA/cacert.pem )],
+    'MozRepl.pm'                        => sub {
         qw( MozRepl/Log.pm MozRepl/Client.pm Module/Pluggable/Fast.pm ),
         _glob_in_inc('MozRepl/Plugin', 1),
     },
-    'Module/Implementation.pm'      => \&_warn_of_runtime_loader,
-    'Module/Runtime.pm'             => \&_warn_of_runtime_loader,
-    'Net/DNS/RR.pm'                 => 'sub',
-    'Net/FTP.pm'                    => 'sub',
-    'Net/HTTPS.pm'                  => [qw( IO/Socket/SSL.pm Net/SSL.pm )],
-    'Net/Server.pm'                 => 'sub',
-    'Net/SSH/Perl.pm'               => 'sub',
-    'Package/Stash.pm'              => [qw( Package/Stash/PP.pm Package/Stash/XS.pm )],
-    'Pango.pm'                      => [qw( Cairo.pm )], # Pango.pm does: eval "use Cairo;"
-    'PAR/Repository.pm'             => 'sub',
-    'PAR/Repository/Client.pm'      => 'sub',
-    'Params/Validate.pm'            => 'sub',
-    'Parse/AFP.pm'                  => 'sub',
-    'Parse/Binary.pm'               => 'sub',
-    'PDF/API2/Resource/Font.pm'     => 'sub',
-    'PDF/API2/Basic/TTF/Font.pm'    => sub {
+    'Module/Implementation.pm'          => \&_warn_of_runtime_loader,
+    'Module/Runtime.pm'                 => \&_warn_of_runtime_loader,
+    'Net/DNS/Resolver.pm'               => 'sub',
+    'Net/DNS/RR.pm'                     => 'sub',
+    'Net/FTP.pm'                        => 'sub',
+    'Net/HTTPS.pm'                      => [qw( IO/Socket/SSL.pm Net/SSL.pm )],
+    'Net/Server.pm'                     => 'sub',
+    'Net/SSH/Perl.pm'                   => 'sub',
+    'Package/Stash.pm'                  => [qw( Package/Stash/PP.pm Package/Stash/XS.pm )],
+    'Pango.pm'                          => [qw( Cairo.pm )], # Pango.pm does: eval "use Cairo;"
+    'PAR/Repository.pm'                 => 'sub',
+    'PAR/Repository/Client.pm'          => 'sub',
+    'Params/Validate.pm'                => 'sub',
+    'Parse/AFP.pm'                      => 'sub',
+    'Parse/Binary.pm'                   => 'sub',
+    'PDF/API2/Resource/Font.pm'         => 'sub',
+    'PDF/API2/Basic/TTF/Font.pm'        => sub {
         _glob_in_inc('PDF/API2/Basic/TTF', 1);
     },
-    'PDF/Writer.pm'                 => 'sub',
-    'PDL/NiceSlice.pm'              => 'sub',
-    'Perl/Critic.pm'                => 'sub', #not only Perl/Critic/Policy
-    'PerlIO.pm'                     => [ 'PerlIO/scalar.pm' ],
-    'Pod/Usage.pm'                  => sub {  # from Pod::Usage (as of 1.61)
+    'PDF/Writer.pm'                     => 'sub',
+    'PDL/NiceSlice.pm'                  => 'sub',
+    'Perl/Critic.pm'                    => 'sub', #not only Perl/Critic/Policy
+    'PerlIO.pm'                         => [qw( PerlIO/scalar.pm )],
+    'Pod/Simple/Transcode.pm'           => [qw( Pod/Simple/TranscodeDumb.pm Pod/Simple/TranscodeSmart.pm )],
+    'Pod/Usage.pm'                      => sub {  # from Pod::Usage (as of 1.61)
          $] >= 5.005_58 ? 'Pod/Text.pm' : 'Pod/PlainText.pm'
      },
-    'POE.pm'                        => [qw( POE/Kernel.pm POE/Session.pm )],
-    'POE/Component/Client/HTTP.pm'  => sub {
+    'POE.pm'                            => [qw( POE/Kernel.pm POE/Session.pm )],
+    'POE/Component/Client/HTTP.pm'      => sub {
         _glob_in_inc('POE/Component/Client/HTTP', 1),
         qw( POE/Filter/HTTPChunk.pm POE/Filter/HTTPHead.pm ),
     },
-    'POE/Kernel.pm'                 => sub {
+    'POE/Kernel.pm'                     => sub {
         _glob_in_inc('POE/XS/Resource', 1),
         _glob_in_inc('POE/Resource', 1),
         _glob_in_inc('POE/XS/Loop', 1),
         _glob_in_inc('POE/Loop', 1),
     },
-    'POSIX.pm'                      => sub {
+    'POSIX.pm'                          => sub {
         map $_->{name},
           _glob_in_inc('auto/POSIX/SigAction', 0),      # *.al files
           _glob_in_inc('auto/POSIX/SigRt', 0),          # *.al files
     },
-    'PPI.pm'                        => 'sub',
-    'Regexp/Common.pm'              => 'sub',
-    'RPC/XML/ParserFactory.pm'      => sub {
+    'PPI.pm'                            => 'sub',
+    'Regexp/Common.pm'                  => 'sub',
+    'RPC/XML/ParserFactory.pm'          => sub {
         _glob_in_inc('RPC/XML/Parser', 1);
     },
-    'SerialJunk.pm' => [ qw(
+    'SerialJunk.pm'                     => [qw(
         termios.ph asm/termios.ph sys/termiox.ph sys/termios.ph sys/ttycom.ph
-    ) ],
-    'SOAP/Lite.pm'                  => sub {
+    )],
+    'SOAP/Lite.pm'                      => sub {
         _glob_in_inc('SOAP/Transport', 1),
         _glob_in_inc('SOAP/Lite', 1),
     },
-    'Socket/GetAddrInfo.pm'         => 'sub',
-    'SQL/Parser.pm' => sub {
+    'Socket/GetAddrInfo.pm'             => 'sub',
+    'Specio/PartialDump.pm'             => \&_unicore,
+    'SQL/Parser.pm'                     => sub {
         _glob_in_inc('SQL/Dialects', 1);
     },
-    'SQL/Translator/Schema.pm' => sub {
+    'SQL/Translator/Schema.pm'          => sub {
         _glob_in_inc('SQL/Translator', 1);
     },
-    'Sub/Exporter/Progressive.pm'   => [qw( Sub/Exporter.pm )],
-    'SVK/Command.pm' => sub {
+    'Sub/Exporter/Progressive.pm'       => [qw( Sub/Exporter.pm )],
+    'SVK/Command.pm'                    => sub {
         _glob_in_inc('SVK', 1);
     },
-    'SVN/Core.pm' => sub {
+    'SVN/Core.pm'                       => sub {
         _glob_in_inc('SVN', 1),
         map $_->{name}, _glob_in_inc('auto/SVN', 0),    # *.so, *.bs files
     },
-    'Template.pm'      => 'sub',
-    'Term/ReadLine.pm' => 'sub',
-    'Test/Deep.pm'     => 'sub',
-    'threads/shared.pm' => [qw( attributes.pm )],
+    'Template.pm'                       => 'sub',
+    'Term/ReadLine.pm'                  => 'sub',
+    'Test/Deep.pm'                      => 'sub',
+    'threads/shared.pm'                 => [qw( attributes.pm )],
     # anybody using threads::shared is likely to declare variables
     # with attribute :shared
-    'Tk.pm'            => sub {
+    'Tk.pm'                             => sub {
         $SeenTk = 1;
         qw( Tk/FileSelect.pm Encode/Unicode.pm );
     },
-    'Tk/Balloon.pm'     => [qw( Tk/balArrow.xbm )],
-    'Tk/BrowseEntry.pm' => [qw( Tk/cbxarrow.xbm Tk/arrowdownwin.xbm )],
-    'Tk/ColorEditor.pm' => [qw( Tk/ColorEdit.xpm )],
-    'Tk/DragDrop/Common.pm' => sub {
+    'Tk/Balloon.pm'                     => [qw( Tk/balArrow.xbm )],
+    'Tk/BrowseEntry.pm'                 => [qw( Tk/cbxarrow.xbm Tk/arrowdownwin.xbm )],
+    'Tk/ColorEditor.pm'                 => [qw( Tk/ColorEdit.xpm )],
+    'Tk/DragDrop/Common.pm'             => sub {
         _glob_in_inc('Tk/DragDrop', 1),
     },
-    'Tk/FBox.pm'        => [qw( Tk/folder.xpm Tk/file.xpm )],
-    'Tk/Getopt.pm'      => [qw( Tk/openfolder.xpm Tk/win.xbm )],
-    'Tk/Toplevel.pm'    => [qw( Tk/Wm.pm )],
-    'Unicode/UCD.pm'    => [qw( utf8_heavy.pl )],
-    'URI.pm'            => sub { grep !/urn/, _glob_in_inc('URI', 1) },
-    'utf8_heavy.pl'     => \&_unicore,
-    'Win32/EventLog.pm'    => [qw( Win32/IPC.pm )],
-    'Win32/Exe.pm'         => 'sub',
-    'Win32/TieRegistry.pm' => [qw( Win32API/Registry.pm )],
-    'Win32/SystemInfo.pm'  => [qw( Win32/cpuspd.dll )],
-    'Wx.pm'                => [qw( attributes.pm )],
-    'XML/Parser.pm'        => sub {
+    'Tk/FBox.pm'                        => [qw( Tk/folder.xpm Tk/file.xpm )],
+    'Tk/Getopt.pm'                      => [qw( Tk/openfolder.xpm Tk/win.xbm )],
+    'Tk/Toplevel.pm'                    => [qw( Tk/Wm.pm )],
+    'Unicode/Normalize.pm'              => \&_unicore,
+    'Unicode/UCD.pm'                    => \&_unicore,
+    'URI.pm'                            => sub { grep !/urn/, _glob_in_inc('URI', 1) },
+    'utf8_heavy.pl'                     => \&_unicore,
+    'Win32/EventLog.pm'                 => [qw( Win32/IPC.pm )],
+    'Win32/Exe.pm'                      => 'sub',
+    'Win32/TieRegistry.pm'              => [qw( Win32API/Registry.pm )],
+    'Win32/SystemInfo.pm'               => [qw( Win32/cpuspd.dll )],
+    'Wx.pm'                             => [qw( attributes.pm )],
+    'XML/Parser.pm'                     => sub {
         _glob_in_inc('XML/Parser/Style', 1),
         _glob_in_inc('XML/Parser/Encodings', 1),
     },
-    'XML/SAX.pm' => [qw( XML/SAX/ParserDetails.ini ) ],
-    'XMLRPC/Lite.pm' => sub {
-        _glob_in_inc('XMLRPC/Transport', 1),;
+    'XML/SAX.pm'                        => [qw( XML/SAX/ParserDetails.ini ) ],
+    'XMLRPC/Lite.pm'                    => sub {
+        _glob_in_inc('XMLRPC/Transport', 1);
     },
-    'YAML.pm'           => [qw( YAML/Loader.pm YAML/Dumper.pm )],
-    'YAML/Any.pm'       => sub { 
+    'YAML.pm'                           => [qw( YAML/Loader.pm YAML/Dumper.pm )],
+    'YAML/Any.pm'                       => sub { 
         # try to figure out what YAML::Any would have used
         my $impl = eval "use YAML::Any; YAML::Any->implementation;";
         unless ($@) 
@@ -716,12 +724,11 @@ sub scan_deps_static {
 
 sub scan_deps_runtime {
     my %args = (
-        perl => $^X,
         rv   => {},
         (@_ and $_[0] =~ /^(?:$Keys)$/o) ? @_ : (files => [@_], recurse => 1)
     );
-    my ($files, $rv, $execute, $compile, $skip, $perl) =
-      @args{qw( files rv execute compile skip perl )};
+    my ($files, $rv, $execute, $compile) =
+      @args{qw( files rv execute compile )};
 
     $files = (ref($files)) ? $files : [$files];
 
@@ -729,20 +736,15 @@ sub scan_deps_runtime {
         foreach my $file (@$files) {
             next unless $file =~ $ScanFileRE;
 
-            my ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
-            _compile_or_execute($perl, $file, undef,
-                                $inchash, $dl_shared_objects, $incarray);
-
+            my ($inchash, $dl_shared_objects, $incarray) = _compile_or_execute($file);
             _merge_rv(_make_rv($inchash, $dl_shared_objects, $incarray), $rv);
         }
     }
     elsif ($execute) {
         foreach my $file (@$files) {
             $execute = [] unless ref $execute;  # make sure it's an array ref
-            my ($inchash, $dl_shared_objects, $incarray) = ({}, [], []);
-            _compile_or_execute($perl, $file, $execute,
-                                $inchash, $dl_shared_objects, $incarray);
 
+            my ($inchash, $dl_shared_objects, $incarray) = _compile_or_execute($file, $execute);
             _merge_rv(_make_rv($inchash, $dl_shared_objects, $incarray), $rv);
         }
     }
@@ -1181,9 +1183,36 @@ sub _glob_in_inc {
     return @files;
 }
 
+# like _glob_in_inc, but looks only at the first level
+# (i.e. the children of $subdir)
+# NOTE: File::Find has no public notion of the depth of the traversal
+# in its "wanted" callback, so it's not helpful 
+sub _glob_in_inc_1 {
+    my $subdir  = shift;
+    my $pm_only = shift;
+    my @files;
+
+    $subdir =~ s/\$CurrentPackage/$CurrentPackage/;
+
+    foreach my $inc (grep !/\bBSDPAN\b/, @INC, @IncludeLibs) {
+        my $dir = "$inc/$subdir";
+        next unless -d $dir;
+
+        opendir my $dh, $dir or next; 
+        my @names = map { "$subdir/$_" } grep { -f "$dir/$_" } readdir $dh;
+        closedir $dh;
+
+        push @files, $pm_only
+            ? ( grep { /\.p[mh]$/i } @names )
+            : ( map { { file => "$inc/$_", name => $_ } } @names );
+    }
+
+    return @files;
+}
+
 my $unicore_stuff;
 sub _unicore {
-    $unicore_stuff ||= [ map $_->{name}, _glob_in_inc('unicore', 0) ];
+    $unicore_stuff ||= [ 'utf8_heavy.pl', map $_->{name}, _glob_in_inc('unicore', 0) ];
     return @$unicore_stuff;
 }
 
@@ -1295,26 +1324,26 @@ sub add_preload_rule {
 # compile $file if $execute is undef,
 # otherwise execute $file with arguments @$execute
 sub _compile_or_execute {
-    my ($perl, $file, $execute, $inchash, $dl_shared_objects, $incarray) = @_;
+    my ($file, $execute) = @_;
 
-    my ($fh, $instrumented_file) = File::Temp::tempfile();
+    my ($ih, $instrumented_file) = File::Temp::tempfile(UNLINK => 1);
 
     # spoof $0 (to $file) so that FindBin works as expected
     # NOTE: We don't directly assign to $0 as it has magic (i.e.
     # assigning has side effects and may actually fail, cf. perlvar(1)).
     # Instead we alias *0 to a package variable holding the correct value.
     local $ENV{MSD_ORIGINAL_FILE} = $file;
-    print $fh <<'...';
+    print $ih <<'...';
 BEGIN { my $_0 = $ENV{MSD_ORIGINAL_FILE}; *0 = \$_0; }
 ...
 
-    my (undef, $data_file) = File::Temp::tempfile();
+    my (undef, $data_file) = File::Temp::tempfile(UNLINK => 1);
     local $ENV{MSD_DATA_FILE} = $data_file;
 
     # NOTE: When compiling the block will run as the last CHECK block;
     # when executing the block will run as the first END block and 
     # the programs continues.
-    print $fh $execute ? "END\n" : "CHECK\n", <<'...';
+    print $ih $execute ? "END\n" : "CHECK\n", <<'...';
 {
     # save %INC etc so that requires below don't pollute them
     my %_INC = %INC;
@@ -1400,29 +1429,26 @@ BEGIN { my $_0 = $ENV{MSD_ORIGINAL_FILE}; *0 = \$_0; }
 
     # append the file to compile or execute
     {
-        open my $in, "<", $file or die "Couldn't open $file: $!";
-        print $fh qq[#line 1 "$file"\n], <$in>;
-        close $in;
+        open my $fh, "<", $file or die "Couldn't open $file: $!";
+        print $ih qq[#line 1 "$file"\n], <$fh>;
+        close $fh;
     }
-    close $fh;
+    close $ih;
 
     # run the instrumented file
-    my @cmd = ($perl);
-    push @cmd, "-c" unless $execute;
-    push @cmd, map { "-I$_" } @IncludeLibs;
-    push @cmd, $instrumented_file;
-    push @cmd, @$execute if $execute;
-    my $rc = system(@cmd);
-
-    _extract_info($data_file, $inchash, $dl_shared_objects, $incarray) 
-        if $rc == 0;
-
-    unlink($instrumented_file, $data_file);
+    my $rc = system(
+        $^X,
+        $execute ? () : ("-c"),
+        (map { "-I$_" } @IncludeLibs),
+        $instrumented_file,
+        $execute ? @$execute : ());
 
     die $execute
         ? "SYSTEM ERROR in executing $file @$execute: $rc" 
         : "SYSTEM ERROR in compiling $file: $rc" 
         unless $rc == 0;
+    
+    return _extract_info($data_file);
 }
 
 # create a new hashref, applying fixups
@@ -1465,7 +1491,7 @@ sub _make_rv {
 }
 
 sub _extract_info {
-    my ($fname, $inchash, $dl_shared_objects, $incarray) = @_;
+    my ($fname) = @_;
 
     use vars qw(%inchash @dl_shared_objects @incarray);
 
@@ -1474,9 +1500,10 @@ sub _extract_info {
             $@ || "can't read $fname: $!";
     }
 
-    $inchash->{$_} = $inchash{$_} for keys %inchash;
-    @$dl_shared_objects = @dl_shared_objects;
-    @$incarray          = @incarray;
+    my %ih = %inchash;
+    my @dso = @dl_shared_objects;
+    my @ia = @incarray;
+    return (\%ih, \@dso, \@ia);
 }
 
 sub _gettype {
@@ -1629,8 +1656,7 @@ B<Perl2Exe> by IndigoStar, Inc L<http://www.indigostar.com/>
 
 The B<scan_deps_runtime> function is contributed by Edward S. Peschko.
 
-L<http://par.perl.org/> is the official website for this module.  You
-can write to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty
+You can write to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty
 mail to E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
 
 Please submit bug reports to E<lt>bug-Module-ScanDeps@rt.cpan.orgE<gt>.
